@@ -31,9 +31,12 @@
     warnings
 )]
 
-#[cfg(feature = "std")]
+#[cfg(feature = "derive")]
 #[macro_use]
 extern crate amplify_derive;
+#[cfg(feature = "derive")]
+pub use amplify_derive::{Wrapper, Display, AsAny, From, Getters, Error};
+
 #[cfg(feature = "serde")]
 extern crate serde_crate as serde;
 #[cfg(feature = "stringly_conversions")]
@@ -42,6 +45,8 @@ pub extern crate stringly_conversions;
 pub use stringly_conversions::*;
 #[cfg(feature = "proc_attr")]
 pub extern crate amplify_syn as proc_attr;
+#[cfg(feature = "proc_attr")]
+pub use proc_attr::ident;
 
 #[macro_use]
 mod macros;
@@ -51,7 +56,7 @@ mod wrapper;
 mod as_any;
 mod bipolar;
 mod dumb_default;
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "derive"))]
 mod io_error;
 #[cfg(feature = "c_raw")]
 mod raw;
@@ -59,6 +64,12 @@ pub mod strategy;
 #[cfg(feature = "serde")]
 mod to_serde_string;
 
+#[cfg(feature = "std")]
+pub mod flags;
+#[cfg(feature = "std")]
+pub mod hex;
+pub mod num;
+
 pub use crate::as_any::AsAny;
 pub use crate::bipolar::Bipolar;
 pub use crate::strategy::Holder;
@@ -66,5 +77,5 @@ pub use crate::wrapper::Wrapper;
 pub use crate::dumb_default::DumbDefault;
 #[cfg(feature = "serde")]
 pub use crate::to_serde_string::{ToYamlString, ToJsonString, ToTomlString};
-#[cfg(feature = "std")]
+#[cfg(all(feature = "std", feature = "derive"))]
 pub use crate::io_error::IoError;
